Learn R Programming

BayesSenMC (version 0.1.5)

BayesSenMC-package: The 'BayesSenMC' package.

Description

This package generates different posterior distributions of adjusted odds ratio under different priors of sensitivity and specificity, and plots the models for comparison. It also provides estimations for the specifications of the models using diagnostics of exposure status with a non-linear mixed effects model.

Arguments

References

Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.21.2. https://mc-stan.org