Learn R Programming

BayesSenMC (version 0.1.5)

bd_meta: Meta-analysis data on Bipolar Disorder diagnosis accuracy

Description

Records the true positive, true negative, false positive and false negative of each diagnosis accuracy study. Also includes the type of screening instruments (Bipolar Spectrum diagnostic scale / HCL-21 / Mood disorder questionnaire), the cut-off value for diagnostics, and the percentage of bipolar cases that were of bipolar disorder type II or not specified.

Usage

data(bd_meta)

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 55 rows and 8 columns.

References

Carvalho et al. (2015) "Screening for bipolar spectrum disorders: A comprehensive meta-analysis of accuracy studies". Journal of Affective Disorders 172: 337 - 346. (ScienceDirect)

Examples

Run this code
data(bd_meta)

Run the code above in your browser using DataLab